<?php
if (!defined('BASEPATH')) {
    exit('No direct script access allowed');
}

if (!function_exists('ehtml')) {

    /**
     * @param string $html
     * @return string
     */
    function ehtml($html)
    {
        return get_instance()->load->library('inlineeditor/inline_text')
            ->set_admin_segment('html')
            ->parse($html);
    }
}

if (!function_exists('etext')) {

    /**
     * @param string $text
     * @return string
     */
    function etext($text)
    {
        return get_instance()->load->library('inlineeditor/inline_text')
            ->set_admin_segment('text')
            ->parse($text);
    }
}

if (!function_exists('elabel')) {

    /**
     * @param string $label
     * @return string
     */
    function elabel($label)
    {
        return get_instance()->load->library('inlineeditor/inline_text')
            ->set_admin_segment('label')
            ->parse($label);
    }
}