.inline_edit_link {
    font-size: 12px;
    background: #ff9;
    color: #444;
    border-radius: 3px;
    display: inline-block;
    height: 25px;
    line-height: 30px;
    text-decoration: none;
    padding: 0 10px;
    position: relative;
    z-index: 999;
}